@@ -26,6 +26,7 @@
 #include "kdeplatformfiledialoghelper.h"
 #include "kdeplatformsystemtrayicon.h"
 #include "kwaylandintegration.h"
+#include "x11integration.h"
 
 #include <QCoreApplication>
 #include <QGuiApplication>
@@ -35,6 +36,7 @@
 #include <QStringList>
 #include <QVariant>
 #include <QDebug>
+#include <QX11Info>
 
 #include <kiconengine.h>
 #include <kiconloader.h>
@@ -48,6 +50,9 @@ KdePlatformTheme::KdePlatformTheme()
     if (QGuiApplication::platformName().startsWith(QLatin1String("wayland"))) {
         m_kwaylandIntegration.reset(new KWaylandIntegration());
         m_kwaylandIntegration->init();
+    } else if (QX11Info::isPlatformX11()) {
+        m_x11Integration.reset(new X11Integration());
+        m_x11Integration->init();
     }
 }
 
